pub struct IdmFrame<'a> {
pub version: u8,
pub final_: u8,
pub encoding: u16,
pub data: &'a [u8],
}Expand description
An IDM Frame
Fields
version: u8The version field. Only version 1 or 2 are currently defined, which are encoded as the values 1 and 2, respectively.
final_: u8The final field. This frame is the final frame containing the complete IDM PDU if this is set to 1. It is not the final frame if this is set to 0. All other values are unspecified, but you should probably close the connection if anything else is used.
encoding: u16The encoding field of a version 2 IDM frame. This is always set to zero for version 1 IDM frames.
data: &'a [u8]The data fragment carried by the IDM frame.